@@ -1,4 +1,5 @@
-/*	Copyright (C) 2004 Bart
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,15 +9,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#ifndef DEVICE
-#define DEVICE
+
+#ifndef GPARTED_DEVICE_H
+#define GPARTED_DEVICE_H
 
 #include "../include/Partition.h"
 
@@ -30,11 +30,15 @@ public:
 	Device() ;
 	~Device() ;
 
+	Device get_copy_without_partitions() const;
 	void add_path( const Glib::ustring & path, bool clear_paths = false ) ;
 	void add_paths( const std::vector<Glib::ustring> & paths, bool clear_paths = false ) ;
 	Glib::ustring get_path() const ;
 	std::vector<Glib::ustring> get_paths() const ;
-	
+	void enable_partition_naming( int length );  // > 0 => enable partition naming support
+	bool partition_naming_supported() const;
+	int get_max_partition_name_length() const;
+
 	bool operator==( const Device & device ) const ;
 	bool operator!=( const Device & device ) const ;
 	
@@ -46,20 +50,22 @@ public:
 	Sector cylinders ;
 	Sector cylsize ;
 	Glib::ustring model;
+	Glib::ustring serial_number;
  	Glib::ustring disktype;
+	int sector_size ;
 	int max_prims ;
 	int highest_busy ;
 	bool readonly ; 
-			
+
 private:
 	void sort_paths_and_remove_duplicates() ;
 
 	static bool compare_paths( const Glib::ustring & A, const Glib::ustring & B ) ;
 	
 	std::vector<Glib::ustring> paths ;
-		
+	int max_partition_name_length;  // > 0 => naming of partitions is supported on this device
 };
  
 } //GParted
- 
-#endif //DEVICE
+
+#endif /* GPARTED_DEVICE_H */
