@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004-2006 Bart 'plors' Hakvoort
+ * Copyright (C) 2008 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,22 +9,22 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#ifndef DIALOG_FEATURES
-#define DIALOG_FEATURES
+
+#ifndef GPARTED_DIALOGFEATURES_H
+#define GPARTED_DIALOGFEATURES_H
 
 #include "../include/Utils.h"
 
 #include <gtkmm/dialog.h>
-#include <gtkmm/expander.h>
+#include <gtkmm/frame.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/liststore.h>
+#include <gtkmm/scrolledwindow.h>
 #include <gtkmm/image.h>
 
 namespace GParted
@@ -40,26 +41,25 @@ public:
 private:
 	void show_filesystem( const FS & fs ) ;
 
-	Gtk::HBox *hbox ;
-	Gtk::HBox *hbox2 ;
-	Gtk::VBox *vbox ;
-	Gtk::Image *image ;
-	Gtk::Expander expander_legend ;
+	Gtk::Frame legend_frame ;
 	Gtk::TreeView treeview_filesystems;
 	Gtk::TreeRow treerow;
+	Gtk::ScrolledWindow filesystems_scrolled ;
 	Glib::RefPtr<Gtk::ListStore> liststore_filesystems;
-	Glib::ustring str_temp ;
 	
 	struct treeview_filesystems_Columns : public Gtk::TreeModelColumnRecord             
 	{
 		Gtk::TreeModelColumn<Glib::ustring> filesystem;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > create ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > grow ;
+		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > online_grow ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > shrink ;
+		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > online_shrink ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > move ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > copy ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > check ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > label ;
+		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > uuid ;
 		Gtk::TreeModelColumn<Glib::ustring> software ;
 				
 		treeview_filesystems_Columns() 
@@ -67,20 +67,23 @@ private:
 			add( filesystem );
 			add( create ) ;
 			add( grow ) ;
+			add( online_grow ) ;
 			add( shrink ) ;
+			add( online_shrink ) ;
 			add( move ) ;
 			add( copy ) ;
 			add( check ) ;
 			add( label ) ;
+			add( uuid ) ;
 			add( software ) ;
 		}
 	};
 	
 	treeview_filesystems_Columns treeview_filesystems_columns ;
 
-	Glib::RefPtr<Gdk::Pixbuf> icon_yes, icon_no ;
+	Glib::RefPtr<Gdk::Pixbuf> icon_yes, icon_no, icon_blank ;
 };
 
 } //GParted
 
-#endif //DIALOG_FEATURES
+#endif /* GPARTED_DIALOGFEATURES_H */
