@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,15 +9,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#ifndef DIALOG_BASE_PARTITION
-#define DIALOG_BASE_PARTITION
+
+#ifndef GPARTED_DIALOG_BASE_PARTITION_H
+#define GPARTED_DIALOG_BASE_PARTITION_H
 
 #include "../include/Frame_Resizer_Extended.h"
 #include "../include/Partition.h"
@@ -28,6 +28,7 @@
 #include <gtkmm/table.h>
 #include <gtkmm/box.h>
 #include <gtkmm/tooltips.h>
+#include <gtkmm/optionmenu.h>
 
 namespace GParted
 {
@@ -40,7 +41,7 @@ public:
 	~Dialog_Base_Partition( ) ;
 
 	void Set_Resizer( bool extended ) ;
-	Partition Get_New_Partition( ) ;
+	const Partition & Get_New_Partition( Byte_Value sector_size );
 	
 protected:
 	enum SPINBUTTON {
@@ -54,25 +55,35 @@ protected:
 		NEW		= 1,
 		PASTE		= 2
 	};
-	
+
+	void prepare_new_partition( Byte_Value sector_size );
+
 	void Set_Confirm_Button( CONFIRMBUTTON button_type ) ;
 	void Set_MinMax_Text( Sector min, Sector max ) ;
 
 	double MB_PER_PIXEL ;
 	Sector TOTAL_MB ;
 	Frame_Resizer_Base *frame_resizer_base;
-	Partition selected_partition ;
-	
+	Partition new_partition;
+
 	Sector START; //the first sector of the first relevant partition ( this is either current or current -1 )  needed in Get_Resized_Partition()
 	Sector total_length ; //total amount of sectors ( this can be up to 3 partitions...)
 
 	Gtk::HBox hbox_main ;
 	Gtk::SpinButton spinbutton_before, spinbutton_size, spinbutton_after;
-	Gtk::CheckButton checkbutton_round_to_cylinders ;
+	Gtk::OptionMenu optionmenu_alignment ;
+	Gtk::Menu menu_alignment ;
+
+	sigc::connection before_change_connection, size_change_connection, after_change_connection ;
 
 	//used to enable/disable OKbutton...
 	int ORIG_BEFORE, ORIG_SIZE, ORIG_AFTER ;
-	
+
+	//used to reserve space for Master or Extended Boot Record (1 MiB)
+	int MIN_SPACE_BEFORE_MB ;
+
+	int MB_Needed_for_Boot_Record( const Partition & partition ) ;
+
 	//signal handlers
 	void on_signal_move( int, int );
 	void on_signal_resize( int, int, Frame_Resizer_Base::ArrowType );
@@ -81,22 +92,17 @@ protected:
 	bool fixed_start, GRIP ;
 	double before_value ;
 	FS fs ;
-	short BUF ; //used in resize and copy ( safety reasons )
-	
+
 private:
 	void Check_Change( ) ;
 	
 	Gtk::VBox vbox_resize_move;
 	Gtk::Label label_minmax ;
 	Gtk::Table table_resize;
-	Gtk::HBox hbox_table, hbox_resizer, hbox_resize_move;
-	Gtk::Tooltips tooltips;
+	Gtk::HBox hbox_table, hbox_resizer;
 	Gtk::Button button_resize_move ;
-	Gtk::Image *image_temp ;
-
-	Glib::ustring str_temp ;
 };
 
 } //GParted
 
-#endif //DIALOG_BASE_PARTITION
+#endif /* GPARTED_DIALOG_BASE_PARTITION_H */
