@@ -8,18 +8,18 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
 
-#ifndef DIALOG_DISKLABEL
-#define DIALOG_DISKLABEL
+
+#ifndef GPARTED_DIALOG_DISKLABEL_H
+#define GPARTED_DIALOG_DISKLABEL_H
 
 #include "../include/Utils.h"
+#include "../include/Device.h"
 
 #include <gtkmm/dialog.h>
 #include <gtkmm/button.h>
@@ -33,21 +33,16 @@ namespace GParted
 class Dialog_Disklabel : public Gtk::Dialog
 {
 public:
-	Dialog_Disklabel( const Glib::ustring & device_path, const std::vector<Glib::ustring> & disklabeltypes ) ;
-	
+	Dialog_Disklabel( const Device & device ) ;
+
 	Glib::ustring Get_Disklabel( ) ;
 	
 private:
-	Gtk::Expander expander_advanced ;
-	Gtk::HBox *hbox ;
-	Gtk::VBox *vbox ;
 	Gtk::Image image ;
 	Gtk::ComboBoxText combo_labeltypes ;
-	Glib::ustring str_temp ;
 	std::vector<Glib::ustring> labeltypes ;
 };
 
 } //GParted
 
-
-#endif //DIALOG_DISKLABEL
+#endif /* GPARTED_DIALOG_DISKLABEL_H */
