@@ -1,4 +1,5 @@
-/*  Copyright (C) 2004 Bart
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,15 +9,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#ifndef DIALOG_PARTITION_COPY
-#define DIALOG_PARTITION_COPY
+
+#ifndef GPARTED_DIALOG_PARTITION_COPY_H
+#define GPARTED_DIALOG_PARTITION_COPY_H
 
 #include "../include/Dialog_Base_Partition.h"
 
@@ -26,14 +26,15 @@ namespace GParted
 class Dialog_Partition_Copy : public Dialog_Base_Partition
 {
 public:
-	Dialog_Partition_Copy( const FS & fs, Sector cylinder_size ) ;
-	void Set_Data( const Partition & selected_partition, const Partition & copied_partition );
+	Dialog_Partition_Copy( const FS & fs, const Partition & selected_partition,
+	                       const Partition & copied_partition );
 
-	Partition Get_New_Partition() ;
+	const Partition & Get_New_Partition( Byte_Value sector_size );
 
 private:
+	void set_data( const Partition & selected_partition, const Partition & copied_partition );
 };
 
 }//GParted
 
-#endif //DIALOG_PARTITION_COPY
+#endif /* GPARTED_DIALOG_PARTITION_COPY_H */
