@@ -8,15 +8,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DIALOG_PARTITION_INFO
-#define DIALOG_PARTITION_INFO
+#ifndef GPARTED_DIALOG_PARTITION_INFO_H
+#define GPARTED_DIALOG_PARTITION_INFO_H
 
 //what kind of info would one prefer to see here?
 //my guess is, it's best to keep the amount of info minimal and wait for users requests
@@ -28,12 +27,13 @@
 #include <gtkmm/stock.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/drawingarea.h>
+#include <gtkmm/scrolledwindow.h>
 #include <gtkmm/table.h>
 
 #define BORDER 8
- 
+
 namespace GParted
-{ 
+{
 
 class Dialog_Partition_Info : public Gtk::Dialog
 {
@@ -49,22 +49,22 @@ private:
 	void drawingarea_on_realize();
 	bool drawingarea_on_expose( GdkEventExpose *ev );
 
-	Partition partition ;
+	const Partition & partition;  // (Alias to element in Win_GParted::display_partitions[] vector).
 
 	Gtk::HBox *hbox ;
 	Gtk::DrawingArea drawingarea ;
 	Gtk::Frame *frame ;
-	Gtk::Image *image;
-	Gtk::Table *table;
+	Gtk::VBox info_msg_vbox ;
+	Gtk::ScrolledWindow info_scrolled ;
 
 	Glib::RefPtr<Gdk::GC> gc;
 	Glib::RefPtr<Pango::Layout> pango_layout;
 
-	Gdk::Color color_partition, color_used, color_unused, color_text ;
+	Gdk::Color color_partition, color_used, color_unused, color_unallocated, color_text ;
 
-	int used,unused ;
+	int used, unused, unallocated ;
 };
 
 } //GParted
 
-#endif //DIALOG_PARTITION_INFO
+#endif /* GPARTED_DIALOG_PARTITION_INFO_H */
