@@ -8,15 +8,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OPERATIONCOPY
-#define OPERATIONCOPY
+#ifndef GPARTED_OPERATIONCOPY_H
+#define GPARTED_OPERATIONCOPY_H
 
 #include "../include/Operation.h"
 
@@ -37,8 +36,9 @@ public:
 
 private:
 	void create_description() ;
+	bool merge_operations( const Operation & candidate );
 } ;
 
 } //GParted
 
-#endif //OPERATIONCOPY
+#endif /* GPARTED_OPERATIONCOPY_H */
