@@ -8,15 +8,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OPERATION_DELETE
-#define OPERATION_DELETE
+#ifndef GPARTED_OPERATIONDELETE_H
+#define GPARTED_OPERATIONDELETE_H
 
 #include "../include/Operation.h"
 
@@ -32,9 +31,10 @@ public:
 		
 private:
 	void create_description() ;
+	bool merge_operations( const Operation & candidate );
 	void remove_original_and_adjacent_unallocated( std::vector<Partition> & partitions, int index_orig ) ;
 } ;
 
 } //GParted
 
-#endif //OPERATION_DELETE
+#endif /* GPARTED_OPERATIONDELETE_H */
