@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart 'plors' Hakvoort
+ * Copyright (C) 2008 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,15 +9,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OPERATIONDETAIL
-#define OPERATIONDETAIL
+#ifndef GPARTED_OPERATIONDETAIL_H
+#define GPARTED_OPERATIONDETAIL_H
 
 #include <glibmm/ustring.h>
 #include <glibmm/markup.h>
@@ -47,6 +47,7 @@ class OperationDetail
 {
 public:	
 	OperationDetail() ;
+	~OperationDetail();
 	OperationDetail( const Glib::ustring & description,
 			 OperationDetailStatus status = STATUS_EXECUTE,
 			 Font font = FONT_NORMAL ) ;
@@ -59,29 +60,29 @@ public:
 	Glib::ustring get_elapsed_time() const ;
 	
 	void add_child( const OperationDetail & operationdetail ) ;
-	std::vector<OperationDetail> & get_childs() ;
-	const std::vector<OperationDetail> & get_childs() const ;
+	std::vector<OperationDetail*> & get_childs() ;
+	const std::vector<OperationDetail*> & get_childs() const ;
 	OperationDetail & get_last_child() ;
 
 	double fraction ;
 	Glib::ustring progress_text ;
 	
 	sigc::signal< void, const OperationDetail & > signal_update ;
-
+	sigc::signal< void, bool > signal_cancel;
+	char cancelflag;
 private:
 	void on_update( const OperationDetail & operationdetail ) ;
-	
+	void cancel( bool force );
 	Glib::ustring description ;
 	OperationDetailStatus status ; 
 
 	Glib::ustring treepath ;
 	
-	std::vector<OperationDetail> sub_details ; 	
+	std::vector<OperationDetail*> sub_details;
 	std::time_t time_start, time_elapsed ;
+	sigc::connection cancelconnection;
 };
 
 } //GParted
 
-
-#endif //OPERATIONDETAIL
-
+#endif /* GPARTED_OPERATIONDETAIL_H */
