@@ -8,15 +8,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#ifndef TREEVIEW_DETAIL
-#define TREEVIEW_DETAIL
+
+#ifndef GPARTED_TREEVIEW_DETAIL_H
+#define GPARTED_TREEVIEW_DETAIL_H
 
 #include "../include/Partition.h"
 
@@ -37,20 +36,22 @@ class TreeView_Detail : public Gtk::TreeView
 public:
 	TreeView_Detail();
 	void load_partitions( const std::vector<Partition> & partitions ) ;
-	void set_selected( const Partition & partition );
+	void set_selected( const Partition * partition_ptr );
 	void clear() ;
 
-	//signals for interclass communication
-	sigc::signal< void, const Partition &, bool > signal_partition_selected ;
+	// Signals for interclass communication
+	sigc::signal<void, const Partition *, bool> signal_partition_selected;
 	sigc::signal< void > signal_partition_activated ;
 	sigc::signal< void, unsigned int, unsigned int > signal_popup_menu ;
 
 private:
 	void load_partitions( const std::vector<Partition> & partitions,
-			      bool & mountpoints,
-			      bool & labels,
-			      const Gtk::TreeRow & parent_row = Gtk::TreeRow() ) ;
-	bool set_selected( Gtk::TreeModel::Children rows, const Partition & partition, bool inside_extended = false ) ;
+	                      bool & mountpoints,
+	                      bool & labels,
+	                      bool & names,
+	                      const Gtk::TreeRow & parent_row = Gtk::TreeRow() );
+	bool set_selected( Gtk::TreeModel::Children rows,
+	                   const Partition * partition_ptr, bool inside_extended = false );
 	void create_row( const Gtk::TreeRow & treerow, const Partition & partition );
 
 	//(overridden) signals
@@ -67,6 +68,7 @@ private:
 	struct treeview_detail_Columns : public Gtk::TreeModelColumnRecord             
 	{
 		Gtk::TreeModelColumn<Glib::ustring> path;
+		Gtk::TreeModelColumn<Glib::ustring> name;
 		Gtk::TreeModelColumn<Glib::ustring> filesystem;
 		Gtk::TreeModelColumn<Glib::ustring> mountpoint;
 		Gtk::TreeModelColumn<Glib::ustring> label ;
@@ -79,14 +81,15 @@ private:
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > icon1 ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > icon2 ;
 		Gtk::TreeModelColumn<Glib::ustring> flags;
-		Gtk::TreeModelColumn<Partition> partition; //hidden column 
-		
+		Gtk::TreeModelColumn<const Partition *> partition_ptr;  // Hidden column.  (Alias to element in
+		                                                        // Win_GParted::display_partitions[] vector).
+
 		treeview_detail_Columns()
 		{
-			add( path ); add( filesystem ); add( mountpoint ) ; add( label ) ;
+			add( path ); add( name ); add( filesystem ); add( mountpoint ); add( label );
 			add( size ); add( used ); add( unused ); add( color );
 			add( text_color ); add( mount_text_color ); add( icon1 );
-			add( icon2 ) ; add( flags ); add( partition );
+			add( icon2 ); add( flags ); add( partition_ptr );
 		}
 	};
 	
@@ -95,4 +98,4 @@ private:
 
 } //GParted
 
-#endif //TREEVIEW_DETAIL
+#endif /* GPARTED_TREEVIEW_DETAIL_H */
