@@ -1,4 +1,5 @@
-/*	Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,15 +9,14 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
- 
-#ifndef WIN_GPARTED
-#define WIN_GPARTED
+
+#ifndef GPARTED_WIN_GPARTED_H
+#define GPARTED_WIN_GPARTED_H
 
 #include "../include/Device.h"
 #include "../include/DrawingAreaVisualDisk.h"
@@ -25,7 +25,6 @@
 #include "../include/GParted_Core.h"
 #include "../include/HBoxOperations.h" 
 
-#include <sigc++/class_slot.h>
 #include <gtkmm/paned.h>
 #include <gtkmm/toolbar.h>
 #include <gtkmm/separatortoolitem.h>
@@ -38,7 +37,14 @@
 
 namespace GParted
 {
-	
+
+enum MergeType
+{
+	MERGE_LAST_WITH_PREV = 0,
+	MERGE_LAST_WITH_ANY  = 1,
+	MERGE_ALL_ADJACENT   = 2
+};
+
 class Win_GParted : public Gtk::Window
 {
 public:
@@ -49,19 +55,24 @@ private:
 	void init_toolbar() ;
 	void init_partition_menu() ;
 	Gtk::Menu * create_format_menu() ;
+	void create_format_menu_add_item( FILESYSTEM filesystem, bool activate ) ;
 	void init_device_info() ;
 	void init_hpaned_main() ;
 
 	void refresh_combo_devices() ;
 	void show_pulsebar( const Glib::ustring & status_message ) ;
-	
+	void hide_pulsebar();
 	//Fill txtview_device_info_buffer with some information about the selected device
 	void Fill_Label_Device_Info( bool clear = false );
 
-	void Add_Operation( Operation * operation, int index = -1 ) ;
+	void Add_Operation( Operation * operation );
+	bool merge_two_operations( unsigned int first, unsigned int second );
+	void merge_operations( MergeType mergetype );
 	void Refresh_Visual();
+	bool valid_display_partition_ptr( const Partition * partition_ptr );
 	bool Quit_Check_Operations();
 	void set_valid_operations() ;
+	void show_operationslist() ;
 	
 	//convenience functions
 	void toggle_item( bool state, int menu_item, int toolbar_item = -1 )
@@ -90,9 +101,9 @@ private:
 		
 	void allow_format( bool state )	{ 
 		toggle_item( state, MENU_FORMAT ) ; }
-	
-	void allow_toggle_swap_mount_state( bool state )	{ 
-		toggle_item( state, MENU_TOGGLE_MOUNT_SWAP ) ; }
+
+	void allow_toggle_busy_state( bool state )	{
+		toggle_item( state, MENU_TOGGLE_BUSY ) ; }
 
 	void allow_manage_flags( bool state ) {
 		toggle_item( state, MENU_FLAGS ) ; } 
@@ -100,9 +111,15 @@ private:
 	void allow_check( bool state ) {
 		toggle_item( state, MENU_CHECK ) ; } 
 	
-	void allow_label_partition( bool state )	{
+	void allow_label_filesystem( bool state ) {
 		toggle_item( state, MENU_LABEL_PARTITION ) ; } 
 
+	void allow_name_partition( bool state ) {
+		toggle_item( state, MENU_NAME_PARTITION ); }
+
+	void allow_change_uuid( bool state )	{
+		toggle_item( state, MENU_CHANGE_UUID ) ; }
+
 	void allow_info( bool state )	{
 		toggle_item( state, MENU_INFO ) ; } 
 
@@ -121,10 +138,7 @@ private:
 	}
 		
 	//threads..
-	void thread_refresh_devices() ;
-	void thread_unmount_partition( bool * succes, Glib::ustring * error ) ;
-	void thread_mount_partition( Glib::ustring mountpoint, bool * succes, Glib::ustring * error ) ;
-	void thread_toggle_swap( bool * succes, Glib::ustring * error ) ;
+	void unmount_partition( bool * succes, Glib::ustring * error );
 		
 	//signal handlers
 	void open_operationslist() ;
@@ -140,10 +154,12 @@ private:
 	void menu_gparted_quit();
 	void menu_view_harddisk_info();
 	void menu_view_operations();
+	void show_disklabel_unrecognized( Glib::ustring device_name );
+	void show_help_dialog( const Glib::ustring & filename, const Glib::ustring & link_id );
 	void menu_help_contents();
 	void menu_help_about();
 
-	void on_partition_selected( const Partition & partition, bool src_is_treeview ) ;
+	void on_partition_selected( const Partition * partition_ptr, bool src_is_treeview );
 	void on_partition_activated() ;
 	void on_partition_popup_menu( unsigned int button, unsigned int time ) ;
 	
@@ -156,20 +172,30 @@ private:
 	void activate_delete();
 	void activate_info();
 	void activate_format( GParted::FILESYSTEM new_fs );
-	void toggle_swap_mount_state() ;
+	void toggle_busy_state() ;
 	void activate_mount_partition( unsigned int index ) ;
 	void activate_disklabel() ;
+	void activate_attempt_rescue_data();
 	void activate_manage_flags() ;
 	void activate_check() ;
-	void activate_label_partition() ;
-	
+	void activate_change_uuid() ;
+	void activate_label_filesystem();
+	void activate_name_partition();
+
 	void activate_undo();
 	void remove_operation( int index = -1, bool remove_all = false ) ;
+	int  partition_in_operation_queue_count( const Partition & partition ) ;
+	int  active_partitions_on_device_count( const Device & device ) ;
 	void activate_apply();
+	bool remove_non_empty_lvm2_pv_dialog( const OperationType optype ) ;
 
 //private variables
 	unsigned int current_device ;
-	Partition selected_partition, copied_partition;
+	std::vector<Partition> display_partitions;  // Copy of current device's partitions with any pending
+	                                            // operations applied, as currently being shown in the GUI.
+	const Partition * selected_partition_ptr;   // Pointer to the selected partition.  (Alias to element
+	                                            // in Win_GParted::display_partitions[] vector).
+	Partition copied_partition;
 	std::vector<Device> devices;
 	std::vector<Operation *> operations;
 
@@ -199,6 +225,7 @@ private:
 
 	//device combo
 	Glib::RefPtr<Gtk::ListStore> liststore_devices ;
+	sigc::connection combo_devices_changed_connection;
 
 	struct treeview_devices_Columns : public Gtk::TreeModelColumnRecord
 	{
@@ -223,30 +250,31 @@ private:
         MENU_COPY, TOOLBAR_COPY,
         MENU_PASTE, TOOLBAR_PASTE,
         MENU_FORMAT,
-        MENU_TOGGLE_MOUNT_SWAP,
+        MENU_TOGGLE_BUSY,
         MENU_MOUNT,
+	MENU_NAME_PARTITION,
         MENU_FLAGS,
         MENU_CHECK,
-		MENU_LABEL_PARTITION,
+	MENU_LABEL_PARTITION,
+	MENU_CHANGE_UUID,
         MENU_INFO,
         TOOLBAR_UNDO,
         TOOLBAR_APPLY ;
 
 	//usefull variables which are used by many different functions...
-	int index_extended ; //position of the extended partition (-1 means there isn't one)
-	unsigned short primary_count ;//primary_count checks for max. of 4 pimary partitions
 	unsigned short new_count;//new_count keeps track of the new created partitions
 	FS fs ;
 	bool OPERATIONSLIST_OPEN ;
+	Glib::ustring gpart_output;//Output of gpart command
 									
 	GParted_Core gparted_core ;
 	std::vector<Gtk::Label *> device_info ;
 					
 	//stuff for progress overview and pulsebar
-	Glib::Thread *thread ;
-	bool pulse ;
+	bool pulsebar_pulse();
+	sigc::connection pulsetimer;
 };
 
 } //GParted
 
-#endif //WIN_GPARTED
+#endif /* GPARTED_WIN_GPARTED_H */
