@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
 #include "../include/Dialog_Progress.h"
@@ -27,7 +27,6 @@ namespace GParted
 
 Dialog_Progress::Dialog_Progress( const std::vector<Operation *> & operations )
 {
-	this ->set_resizable( false ) ;
 	this ->set_has_separator( false ) ;
 	this ->set_title( _("Applying pending operations") ) ;
 	this ->operations = operations ;
@@ -36,78 +35,77 @@ Dialog_Progress::Dialog_Progress( const std::vector<Operation *> & operations )
 	warnings = 0 ;
 
 	fraction = 1.00 / operations .size() ;
-		
-	dispatcher_update_gui_elements .connect( 
-		sigc::mem_fun( this, &Dialog_Progress::dispatcher_on_update_gui_elements ) ) ;
-			
-	Glib::ustring str_temp = "<span weight=\"bold\" size=\"larger\">" ;
-	str_temp += _("Applying pending operations") ;
-	str_temp += "</span>\n\n" ;
-	str_temp += _("Applying all listed operations.") ;
-	str_temp += "\n";
-	str_temp += _("Depending on the amount and type of operations this might take a long time.") ;
-	str_temp += "\n";
-	this ->get_vbox() ->pack_start( * Utils::mk_label( str_temp ), Gtk::PACK_SHRINK );
-	
-	label_current .set_alignment( Gtk::ALIGN_LEFT );
-	this ->get_vbox() ->pack_start( label_current, Gtk::PACK_SHRINK ) ;
+	this->property_default_width() = 700;
 
-	progressbar_current .set_pulse_step( 0.01 ) ;
-	this->get_vbox() ->pack_start( progressbar_current, Gtk::PACK_SHRINK );
-	
-	label_current_sub .set_alignment( Gtk::ALIGN_LEFT );
-	this ->get_vbox() ->pack_start( label_current_sub, Gtk::PACK_SHRINK );
-	
-	this ->get_vbox() ->pack_start( * Utils::mk_label( "<b>" + Glib::ustring( _("Completed Operations:") ) + "</b>" ),
-					Gtk::PACK_SHRINK );
-	this ->get_vbox() ->pack_start( progressbar_all, Gtk::PACK_SHRINK );
-	
-	//create some icons here, instead of recreating them every time
-	icon_execute = render_icon( Gtk::Stock::EXECUTE, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
-	icon_succes = render_icon( Gtk::Stock::APPLY, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
-	icon_error = render_icon( Gtk::Stock::DIALOG_ERROR, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
-	icon_info = render_icon( Gtk::Stock::INFO, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
-	icon_n_a = render_icon( Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
-	
-	treestore_operations = Gtk::TreeStore::create( treeview_operations_columns );
-	treeview_operations .set_model( treestore_operations );
-	treeview_operations .set_headers_visible( false );
-	treeview_operations .set_rules_hint( true ) ;
-	treeview_operations .set_size_request( 500, 250 ) ;
-	treeview_operations .append_column( "", treeview_operations_columns .operation_description );
-	treeview_operations .append_column( "", treeview_operations_columns .elapsed_time );
-	treeview_operations .append_column( "", treeview_operations_columns .status_icon );
-
-	treeview_operations .get_column( 0 ) ->set_expand( true ) ;
-	treeview_operations .get_column( 0 ) ->set_cell_data_func( 
-		* ( treeview_operations .get_column( 0 ) ->get_first_cell_renderer() ),
-		sigc::mem_fun(*this, &Dialog_Progress::on_cell_data_description) ) ;
-
-	//fill 'er up
-	for ( unsigned int t = 0 ; t < operations .size() ; t++ )
 	{
-		this ->operations[ t ] ->operation_detail .set_description( operations[ t ] ->description, FONT_BOLD ) ;
-		this ->operations[ t ] ->operation_detail .set_treepath( Utils::num_to_str( t ) ) ;
-		
-		treerow = *( treestore_operations ->append() );
-		treerow[ treeview_operations_columns .operation_description ] =
-			this ->operations[ t ] ->operation_detail .get_description() ; 
-	}
-	
-	scrolledwindow .set_shadow_type( Gtk::SHADOW_ETCHED_IN ) ;
-	scrolledwindow .set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC ) ;
-	scrolledwindow .add( treeview_operations ) ;
+		Gtk::VBox* vbox(manage(new Gtk::VBox()));
 
-	expander_details .set_label( "<b>" + Glib::ustring( _("Details") ) + "</b>" ) ;
-	expander_details .set_use_markup( true ) ;
-	expander_details .property_expanded() .signal_changed() .connect(
-   		sigc::mem_fun(*this, &Dialog_Progress::on_expander_changed) );
-	expander_details .add( scrolledwindow ) ;
-	
-	this ->get_vbox() ->pack_start( expander_details, Gtk::PACK_EXPAND_WIDGET ) ; 
-	this ->get_vbox() ->set_spacing( 5 ) ;
-	
-	this ->add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL ) ;
+		vbox->set_border_width(10);
+		this->get_vbox()->pack_start(*vbox, Gtk::PACK_EXPAND_WIDGET);
+
+		Glib::ustring str_temp(_("Depending on the number and type of operations this might take a long time."));
+		str_temp += "\n";
+		vbox->pack_start(*Utils::mk_label(str_temp), Gtk::PACK_SHRINK);
+
+		label_current.set_alignment(Gtk::ALIGN_LEFT);
+		vbox->pack_start(label_current, Gtk::PACK_SHRINK);
+
+		progressbar_current.set_pulse_step(0.01);
+		vbox->pack_start(progressbar_current, Gtk::PACK_SHRINK);
+
+		label_current_sub.set_alignment(Gtk::ALIGN_LEFT);
+		vbox->pack_start(label_current_sub, Gtk::PACK_SHRINK);
+
+		vbox->pack_start(*Utils::mk_label("<b>" + Glib::ustring(_("Completed Operations:")) + "</b>"),
+					Gtk::PACK_SHRINK);
+		vbox->pack_start(progressbar_all, Gtk::PACK_SHRINK);
+
+		//create some icons here, instead of recreating them every time
+		icon_execute = render_icon(Gtk::Stock::EXECUTE, Gtk::ICON_SIZE_LARGE_TOOLBAR);
+		icon_succes = render_icon(Gtk::Stock::APPLY, Gtk::ICON_SIZE_LARGE_TOOLBAR);
+		icon_error = render_icon(Gtk::Stock::DIALOG_ERROR, Gtk::ICON_SIZE_LARGE_TOOLBAR);
+		icon_info = render_icon(Gtk::Stock::INFO, Gtk::ICON_SIZE_LARGE_TOOLBAR);
+		icon_n_a = render_icon(Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_LARGE_TOOLBAR);
+
+		treestore_operations = Gtk::TreeStore::create( treeview_operations_columns);
+		treeview_operations.set_model(treestore_operations);
+		treeview_operations.set_headers_visible(false);
+		treeview_operations.set_rules_hint(true);
+		treeview_operations.set_size_request(700, 250);
+		treeview_operations.append_column("", treeview_operations_columns.operation_description);
+		treeview_operations.append_column("", treeview_operations_columns.elapsed_time);
+		treeview_operations.append_column("", treeview_operations_columns.status_icon);
+
+		treeview_operations.get_column(0)->set_expand(true);
+		treeview_operations.get_column(0)->set_cell_data_func(
+			*(treeview_operations.get_column(0)->get_first_cell_renderer()),
+			sigc::mem_fun(*this, &Dialog_Progress::on_cell_data_description) );
+
+		//fill 'er up
+		for (unsigned int t = 0; t < operations.size(); ++t)
+		{
+			this->operations[t]->operation_detail.set_description(operations[t]->description, FONT_BOLD);
+			this->operations[t]->operation_detail.set_treepath(Utils::num_to_str(t));
+
+			treerow = *(treestore_operations->append());
+			treerow[treeview_operations_columns.operation_description] =
+				this ->operations[t]->operation_detail.get_description();
+		}
+
+		scrolledwindow.set_shadow_type(Gtk::SHADOW_ETCHED_IN);
+		scrolledwindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+		scrolledwindow.set_size_request (700, 250);
+		scrolledwindow.add(treeview_operations);
+
+		expander_details.set_label("<b>" + Glib::ustring(_("Details")) + "</b>");
+		expander_details.set_use_markup(true);
+		expander_details.add(scrolledwindow);
+
+		vbox ->pack_start(expander_details, Gtk::PACK_EXPAND_WIDGET);
+		vbox ->set_spacing(5);
+	}
+
+	cancelbutton = this ->add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
 	
 	this ->signal_show() .connect( sigc::mem_fun(*this, &Dialog_Progress::on_signal_show) );
 	this ->show_all_children() ;
@@ -149,20 +147,23 @@ void Dialog_Progress::on_signal_update( const OperationDetail & operationdetail
 				break ;
 		}
 
-		pulse = operationdetail .fraction < 0 ;
-
 		//update the gui elements..
-		this ->operationdetail = operationdetail ;
+		progress_text = operationdetail.progress_text;
 
 		if ( operationdetail .get_status() == STATUS_EXECUTE )
 			label_current_sub_text = operationdetail .get_description() ;
 
-		dispatcher_update_gui_elements() ;
+		if ( operationdetail.fraction >= 0 ) {
+			pulsetimer.disconnect();
+			progressbar_current.set_fraction( operationdetail.fraction > 1.0 ? 1.0 : operationdetail.fraction );
+		} else if( !pulsetimer.connected() )
+			pulsetimer = Glib::signal_timeout().connect( sigc::mem_fun(*this, &Dialog_Progress::pulsebar_pulse), 100 );
+		update_gui_elements();
 	}
 	else//it's an new od which needs to be added to the model.
 	{
 		unsigned int pos = operationdetail .get_treepath() .rfind( ":" ) ;
-		if ( pos >= 0 && pos < operationdetail .get_treepath() .length() )
+		if ( pos < operationdetail .get_treepath() .length() )
 			iter = treestore_operations ->get_iter( operationdetail .get_treepath() 
 							.substr( 0, operationdetail .get_treepath() .rfind( ":" ) ) ) ;
 		else
@@ -176,15 +177,18 @@ void Dialog_Progress::on_signal_update( const OperationDetail & operationdetail
 	}
 }
 
-void Dialog_Progress::dispatcher_on_update_gui_elements()
+void Dialog_Progress::update_gui_elements()
 {
 	label_current_sub .set_markup( "<i>" + label_current_sub_text + "</i>\n" ) ;
 	
-	if ( operationdetail .fraction >= 0 )
-	{
-		progressbar_current .set_fraction( operationdetail .fraction > 1.0 ? 1.0 : operationdetail .fraction ) ;
-		progressbar_current .set_text( operationdetail .progress_text ) ;
-	}
+	//To ensure progress bar height remains the same, add a space in case message is empty
+	progressbar_current.set_text( progress_text + " " );
+}
+
+bool Dialog_Progress::pulsebar_pulse()
+{
+	progressbar_current.pulse();
+	return true;
 }
 
 void Dialog_Progress::on_signal_show()
@@ -207,20 +211,7 @@ void Dialog_Progress::on_signal_show()
 		//set focus...
 		treeview_operations .set_cursor( static_cast<Gtk::TreePath>( treerow ) ) ;
 		
-		//and start..
-		running = true ;
-		pthread_create( & pthread, NULL, Dialog_Progress::static_pthread_apply_operation, this );
-
-		while ( running )
-		{
-			if ( pulse )
-				progressbar_current .pulse() ;
-			
-			while ( Gtk::Main::events_pending() )
-				Gtk::Main::iteration();
-
-			usleep( 10000 ) ;
-		}
+		succes = signal_apply_operation.emit( operations[t] );
 
 		//set status (succes/error) for this operation
 		operations[ t ] ->operation_detail .set_status( succes ? STATUS_SUCCES : STATUS_ERROR ) ;
@@ -230,10 +221,13 @@ void Dialog_Progress::on_signal_show()
 	this ->add_button( _("_Save Details"), Gtk::RESPONSE_OK ) ; //there's no enum for SAVE
 	
 	//replace 'cancel' with 'close'
-	std::vector<Gtk::Widget *> children = this ->get_action_area() ->get_children() ;
-	this ->get_action_area() ->remove( * children .back() ) ;
+	canceltimer.disconnect();
+	delete cancelbutton;
+	cancelbutton = 0;
 	this ->add_button( Gtk::Stock::CLOSE, Gtk::RESPONSE_CLOSE );
 
+	pulsetimer.disconnect();
+
 	if ( cancel )
 	{
 		progressbar_current .set_text( _("Operation cancelled") ) ;
@@ -250,7 +244,7 @@ void Dialog_Progress::on_signal_show()
 	//deal with succes/error...
 	if ( succes )
 	{
-		str_temp = _("All operations successfully completed") ;
+		Glib::ustring str_temp(_("All operations successfully completed"));
 
 		if ( warnings > 0 )
 			str_temp += " ("
@@ -272,11 +266,13 @@ void Dialog_Progress::on_signal_show()
 						   Gtk::MESSAGE_ERROR,
 						   Gtk::BUTTONS_OK,
 						   true ) ;
-			str_temp = _("See the details for more information.") ;
+			Glib::ustring str_temp(_("See the details for more information."));
+
 			str_temp += "\n\n<i><b>" + Glib::ustring( _("IMPORTANT") ) + "</b>\n" ;
 			str_temp += _("If you want support, you need to provide the saved details!") ;
-			str_temp += "\n" + String::ucompose( 
-				_("See %1 for more information."), "http://gparted.sourceforge.net/larry/tips/save_details.htm" ) + "</i>" ;
+			str_temp += "\n" + String::ucompose(
+					/* TO TRANSLATORS: looks like   See http://gparted.org/save-details.htm for more information. */
+					_("See %1 for more information."), "http://gparted.org/save-details.htm" ) + "</i>" ;
 		
 			dialog .set_secondary_text( str_temp, true ) ;
 			dialog .run() ;
@@ -284,26 +280,25 @@ void Dialog_Progress::on_signal_show()
 	} 
 }
 
-void Dialog_Progress::on_expander_changed() 
-{
-	this ->set_resizable( expander_details .get_expanded() ) ;
-}
-
 void Dialog_Progress::on_cell_data_description( Gtk::CellRenderer * renderer, const Gtk::TreeModel::iterator & iter )
 {
 	dynamic_cast<Gtk::CellRendererText *>( renderer ) ->property_markup() = 
 		static_cast<Gtk::TreeRow>( *iter )[ treeview_operations_columns .operation_description ] ;
 }
 
-void * Dialog_Progress::static_pthread_apply_operation( void * p_dialog_progress ) 
+bool Dialog_Progress::cancel_timeout()
 {
-	Dialog_Progress *dp = static_cast<Dialog_Progress *>( p_dialog_progress ) ;
-	
-	dp ->succes = dp ->signal_apply_operation .emit( dp ->operations[ dp ->t ] ) ;
-	
-	dp ->running = false ;
-
-	return NULL ;
+	if (--cancel_countdown) {
+		/*TO TRANSLATORS: looks like  Force Cancel (5)
+		 *  where the number represents a count down in seconds until the button is enabled */
+		cancelbutton->set_label( String::ucompose( _("Force Cancel (%1)"), cancel_countdown ) );
+	} else {
+		cancelbutton->set_label( _("Force Cancel") );
+		canceltimer.disconnect();
+		cancelbutton->set_sensitive();
+		return false;
+	}
+	return true;
 }
 
 void Dialog_Progress::on_cancel()
@@ -315,17 +310,25 @@ void Dialog_Progress::on_cancel()
 				   Gtk::BUTTONS_NONE,
 				   true ) ;
 		
-	dialog .set_secondary_text( _("Cancelling an operation may cause SEVERE file system damage.") ) ;
+	dialog .set_secondary_text( _("Canceling an operation might cause SEVERE file system damage.") ) ;
 
 	dialog .add_button( _("Continue Operation"), Gtk::RESPONSE_NONE ) ;
 	dialog .add_button( _("Cancel Operation"), Gtk::RESPONSE_CANCEL ) ;
 	
-	if ( dialog .run() == Gtk::RESPONSE_CANCEL )
+	if ( !cancel || dialog .run() == Gtk::RESPONSE_CANCEL )
 	{
-		pthread_cancel( pthread ) ;
-		cancel = true ;
-		running = false ;
-		succes = false ;
+		cancelbutton->set_sensitive( false );
+		if (!cancel) {
+			cancel_countdown = 5;
+			/*TO TRANSLATORS: looks like  Force Cancel (5)
+			 *  where the number represents a count down in seconds until the button is enabled */
+			cancelbutton->set_label( String::ucompose( _("Force Cancel (%1)"), cancel_countdown ) );
+			canceltimer = Glib::signal_timeout().connect(
+				sigc::mem_fun(*this, &Dialog_Progress::cancel_timeout), 1000 );
+		}
+		else cancelbutton->set_label( _("Force Cancel") );
+		operations[t]->operation_detail.signal_cancel( cancel );
+		cancel = true;
 	}
 }
 
@@ -344,14 +347,34 @@ void Dialog_Progress::on_save()
 		std::ofstream out( dialog .get_filename() .c_str() ) ;
 		if ( out )
 		{
-			out << "GParted " << VERSION << "<BR><BR>" << std::endl ;
-			out << "Libparted " << signal_get_libparted_version .emit() << "<BR><BR>" << std::endl ; 
+			//Write out proper HTML start
+			out << "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>" << std::endl
+			<< "<html xmlns='http://www.w3.org/1999/xhtml' xml:lang='" << Utils::get_lang() << "'"
+			<< " lang='" << Utils::get_lang() << "'>" << std::endl
+			<< "<head>" << std::endl
+			<< "<meta http-equiv='Content-Type' content='text/html;charset=utf-8' />" << std::endl
+			<< "<title>" << _("GParted Details") << "</title>" << std::endl
+			<< "</head>" << std::endl
+			<< "<body>" << std::endl
+			<< "<p>" << _("GParted") << " " << VERSION
+#ifdef USE_LIBPARTED_DMRAID
+			<< " --enable-libparted-dmraid"
+#endif
+#ifdef ENABLE_ONLINE_RESIZE
+			<< " --enable-online-resize"
+#endif
+			<< "</p>" << std::endl
+			<< "<p>" << _("Libparted") << " " << signal_get_libparted_version .emit() << "</p>" << std::endl ;
+
+			//Write out each operation
 			for ( unsigned int t = 0 ; t < operations .size() ; t++ )
 			{
 				echo_operation_details( operations[ t ] ->operation_detail, out ) ;
-				out << "<BR>========================================<BR><BR>" << std::endl ;
+				out << "<p>========================================</p>" << std::endl ;
 			}
-				
+
+			//Write out proper HTML finish
+			out << "</body>" << std::endl << "</html>" ;
 			out .close() ;
 		}
 	}
@@ -362,13 +385,13 @@ void Dialog_Progress::echo_operation_details( const OperationDetail & operationd
 	//replace '\n' with '<br>'
 	Glib::ustring temp = operationdetail .get_description() ;
 	for ( unsigned int index = temp .find( "\n" ) ; index < temp .length() ; index = temp .find( "\n" ) )
-		temp .replace( index, 1, "<BR />" ) ;
+		temp .replace( index, 1, "<br />" ) ;
 	
 	//and export everything to some kind of html...
-	out << "<TABLE border=0>" << std::endl ;
-	out << "<TR>" << std::endl ;
-	out << "<TD colspan=2>" << std::endl ;
-	out << temp ;
+	out << "<table border='0'>" << std::endl
+	<< "<tr>" << std::endl
+	<< "<td colspan='2'>" << std::endl
+	<< temp ;
 	if ( ! operationdetail .get_elapsed_time() .empty() )
 		out << "&nbsp;&nbsp;" << operationdetail .get_elapsed_time() ;
 	
@@ -379,19 +402,46 @@ void Dialog_Progress::echo_operation_details( const OperationDetail & operationd
 		switch ( operationdetail .get_status() )
 		{
 			case STATUS_EXECUTE:
-				out << "( EXECUTING )" ;
+				out << "( " <<
+						/* TO TRANSLATORS:  EXECUTING
+						 * means that the status for this operation is
+						 * executing or currently in progress.
+						 */
+						_("EXECUTING") << " )" ;
 				break ;
 			case STATUS_SUCCES:
-				out << "( SUCCESS )" ;
+				out << "( " <<
+						/* TO" TRANSLATORS:  SUCCESS
+						 * means that the status for this operation is
+						 * completed successfully.
+						 */
+						_("SUCCESS") << " )" ;
 				break ;
 			case STATUS_ERROR:
-				out << "( ERROR )" ;
+				out << "( "
+						/* TO TRANSLATORS:  ERROR
+						 * means that the status for this operation is
+						 * completed with errors.
+						 */
+						<< _("ERROR") << " )" ;
 				break ;
 			case STATUS_INFO:
-				out << "( INFO )" ;
+				out << "( " <<
+						/* TO TRANSLATORS:  INFO
+						 * means that the status for this operation is
+						 * for your information , or messages from the
+						 * libparted library.
+						 */
+						_("INFO") << " )" ;
 				break ;
 			case STATUS_N_A:
-				out << "( N/A )" ;
+				out << "( " <<
+						/* TO TRANSLATORS:  N/A
+						 * means that the status for this operation is
+						 * not applicable because the operation is not
+						 * supported on the file system in the partition.
+						 */
+						_("N/A") << " )" ;
 				break ;
 
 			default:
@@ -399,23 +449,21 @@ void Dialog_Progress::echo_operation_details( const OperationDetail & operationd
 		}
 	}
 	
-	out << std::endl ;
-	out << "</TD>" << std::endl ;
-	out << "</TR>" << std::endl ;
+	out << std::endl << "</td>" << std::endl << "</tr>" << std::endl ;
 	
 	if ( operationdetail .get_childs(). size() )
 	{
-		out << "<TR>" << std::endl ;
-		out << "<TD>&nbsp;&nbsp;&nbsp;&nbsp;</TD>" << std::endl ;
-		out << "<TD>" << std::endl ;
+		out << "<tr>" << std::endl
+		<< "<td>&nbsp;&nbsp;&nbsp;&nbsp;</td>" << std::endl
+		<< "<td>" << std::endl ;
 
 		for ( unsigned int t = 0 ; t <  operationdetail .get_childs() .size() ; t++ )
-			echo_operation_details( operationdetail .get_childs()[ t ], out ) ;
+			echo_operation_details( *(operationdetail.get_childs()[ t ]), out );
 
-		out << "</TD>" << std::endl ;
-		out << "</TR>" << std::endl ;
+		out << "</td>" << std::endl << "</tr>" << std::endl ;
 	}
-	out << "</TABLE>" << std::endl ;
+	out << "</table>" << std::endl ;
+	
 }
 
 void Dialog_Progress::on_response( int response_id ) 
@@ -441,6 +489,7 @@ bool Dialog_Progress::on_delete_event( GdkEventAny * event )
 
 Dialog_Progress::~Dialog_Progress()
 {
+	delete cancelbutton;
 }
 
 
