@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart
+ * Copyright (C) 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "../include/DrawingAreaVisualDisk.h"
@@ -36,6 +36,9 @@ DrawingAreaVisualDisk::DrawingAreaVisualDisk()
 	color_unused .set( Utils::get_color( GParted::FS_UNUSED ) );
 	get_colormap() ->alloc_color( color_unused ) ;
 	
+	color_unallocated .set( Utils::get_color( GParted::FS_UNALLOCATED ) );
+	get_colormap() ->alloc_color( color_unallocated ) ;
+
 	color_text .set( "black" );
 	get_colormap() ->alloc_color( color_text ) ;
 
@@ -54,10 +57,10 @@ void DrawingAreaVisualDisk::load_partitions( const std::vector<Partition> & part
 	queue_resize() ;
 }
 
-void DrawingAreaVisualDisk::set_selected( const Partition & partition ) 
+void DrawingAreaVisualDisk::set_selected( const Partition * partition_ptr )
 {
 	selected_vp = NULL ;
-	set_selected( visual_partitions, partition ) ;
+	set_selected( visual_partitions, partition_ptr );
 	
 	queue_draw() ;
 }
@@ -89,25 +92,19 @@ void DrawingAreaVisualDisk::set_static_data( const std::vector<Partition> & part
 	{
 		visual_partitions .push_back( visual_partition() ) ;
 
-		visual_partitions .back() .partition = partitions[ t ] ; 
-		visual_partitions .back() .fraction = partitions[ t ] .get_length() / static_cast<double>( length ) ;
+		visual_partitions.back().partition_ptr = & partitions[t];
+		Sector partition_length = partitions[ t ] .get_sector_length() ;
+		visual_partitions .back() .fraction = partition_length / static_cast<double>( length ) ;
 
-		if ( partitions[ t ] .type == GParted::TYPE_UNALLOCATED || partitions[ t ] .type == GParted::TYPE_EXTENDED )
-			visual_partitions .back() .fraction_used = -1 ;
-		else if ( partitions[ t ] .sectors_used > 0 )
-			visual_partitions .back() .fraction_used = 
-				partitions[ t ] .sectors_used / static_cast<double>( partitions[ t ] .get_length() ) ;
-	
 		visual_partitions .back() .color = partitions[ t ] .color; 
 		get_colormap() ->alloc_color( visual_partitions .back() .color );
 
 		if ( partitions[ t ] .type == GParted::TYPE_EXTENDED )
-			set_static_data( partitions[ t ] .logicals, 
-				      	 visual_partitions .back() .logicals,
-	   			         partitions[ t ] .get_length() ) ;
+			set_static_data( partitions[ t ] .logicals,
+					 visual_partitions .back() .logicals, partition_length ) ;
 		else
 			visual_partitions .back() .pango_layout = create_pango_layout( 
-				partitions[ t ] .get_path() + "\n" + Utils::format_size( partitions[ t ] .get_length() ) ) ;
+				partitions[ t ] .get_path() + "\n" + Utils::format_size( partition_length, partitions[ t ] .sector_size ) ) ;
 	}
 }
 
@@ -151,32 +148,47 @@ void DrawingAreaVisualDisk::calc_position_and_height( std::vector<visual_partiti
 	}
 }
 
-void DrawingAreaVisualDisk::calc_used_unused( std::vector<visual_partition> & visual_partitions ) 
+void DrawingAreaVisualDisk::calc_usage( std::vector<visual_partition> & visual_partitions )
 {
 	for ( unsigned int t = 0 ; t < visual_partitions .size() ; t++ )
 	{
-		if ( visual_partitions[ t ] .fraction_used > -1 )
-		{ 
+		if ( visual_partitions[t].partition_ptr->type != TYPE_UNALLOCATED &&
+		     visual_partitions[t].partition_ptr->type != TYPE_EXTENDED       )
+		{
+			if ( visual_partitions[t].partition_ptr->sector_usage_known() )
+			{
+				visual_partitions[t].partition_ptr->get_usage_triple(
+						visual_partitions[ t ] .length - BORDER *2,
+						visual_partitions[ t ] .used_length,
+						visual_partitions[ t ] .unused_length,
+						visual_partitions[ t ] .unallocated_length ) ;
+			}
+			else
+			{
+				//Specifically show unknown figures as unused
+				visual_partitions[ t ] .used_length        = 0 ;
+				visual_partitions[ t ] .unused_length      = visual_partitions[ t ] .length - BORDER *2 ;
+				visual_partitions[ t ] .unallocated_length = 0 ;
+			}
+
 			//used
 			visual_partitions[ t ] .x_used_start = visual_partitions[ t ] .x_start + BORDER ;
-		
-			if ( visual_partitions[ t ] .fraction_used )
-				visual_partitions[ t ] .used_length =
-					Utils::round( ( visual_partitions[ t ] .length - (2*BORDER) ) * visual_partitions[ t ] .fraction_used ) ;
 
 			//unused
-			visual_partitions[ t ] .x_unused_start = 
-				visual_partitions[ t ] .x_used_start + visual_partitions[ t ] .used_length  ;
-			visual_partitions[ t ] .unused_length = 
-				visual_partitions[ t ] .length - (2 * BORDER) - visual_partitions[ t ] .used_length ;
+			visual_partitions[ t ] .x_unused_start = visual_partitions[ t ] .x_used_start
+			                                       + visual_partitions[ t ] .used_length ;
+
+			//unallocated
+			visual_partitions[ t ] .x_unallocated_start = visual_partitions[ t ] .x_unused_start
+			                                            + visual_partitions[ t ] .unused_length ;
 
 			//y position and height
-			visual_partitions[ t ] .y_used_unused_start = visual_partitions[ t ] .y_start + BORDER ;
-			visual_partitions[ t ] .used_unused_height = visual_partitions[ t ] .height - (2 * BORDER) ;
+			visual_partitions[ t ] .y_usage_start = visual_partitions[ t ] .y_start + BORDER ;
+			visual_partitions[ t ] .usage_height = visual_partitions[ t ] .height - (2 * BORDER) ;
 		}
 
 		if ( visual_partitions[ t ] .logicals .size() > 0 )
-			calc_used_unused( visual_partitions[ t ] .logicals ) ;
+			calc_usage( visual_partitions[ t ] .logicals ) ;
 	}
 }
 	
@@ -225,9 +237,9 @@ void DrawingAreaVisualDisk::draw_partition( const visual_partition & vp )
 		get_window() ->draw_rectangle( gc,
 					       true,
 					       vp .x_used_start, 
-					       vp .y_used_unused_start, 
+					       vp .y_usage_start,
 					       vp .used_length,
-					       vp .used_unused_height );
+					       vp .usage_height );
 	}
 		
 	//unused
@@ -237,9 +249,21 @@ void DrawingAreaVisualDisk::draw_partition( const visual_partition & vp )
 		get_window() ->draw_rectangle( gc,
 					       true,
 					       vp .x_unused_start, 
-					       vp .y_used_unused_start, 
+					       vp .y_usage_start,
 					       vp .unused_length,
-					       vp .used_unused_height );
+					       vp .usage_height );
+	}
+
+	//unallocated
+	if ( vp .unallocated_length > 0 )
+	{
+		gc ->set_foreground( color_unallocated );
+		get_window() ->draw_rectangle( gc,
+					       true,
+					       vp .x_unallocated_start,
+					       vp .y_usage_start,
+					       vp .unallocated_length,
+					       vp .usage_height );
 	}
 
 	//text
@@ -283,14 +307,14 @@ void DrawingAreaVisualDisk::set_selected( const std::vector<visual_partition> &
 }
 
 void DrawingAreaVisualDisk::set_selected( const std::vector<visual_partition> & visual_partitions,
-					  const Partition & partition ) 
+                                          const Partition * partition_ptr )
 {
 	for ( unsigned int t = 0 ; t < visual_partitions .size() && ! selected_vp ; t++ )
 	{
 		if ( visual_partitions[ t ] .logicals .size() > 0 )
-			set_selected( visual_partitions[ t ] .logicals, partition ) ;
+			set_selected( visual_partitions[t].logicals, partition_ptr );
 
-		if ( ! selected_vp && visual_partitions[ t ] .partition == partition )
+		if ( ! selected_vp && *visual_partitions[t].partition_ptr == *partition_ptr )
 			selected_vp = & visual_partitions[ t ] ;
 	}
 }
@@ -337,7 +361,7 @@ bool DrawingAreaVisualDisk::on_button_press_event( GdkEventButton * event )
 	
 	if ( selected_vp )
 	{
-		signal_partition_selected .emit( selected_vp ->partition, false ) ;	
+		signal_partition_selected.emit( selected_vp->partition_ptr, false );
 
 		if ( event ->type == GDK_2BUTTON_PRESS ) 
 			signal_partition_activated .emit() ;
@@ -384,8 +408,9 @@ void DrawingAreaVisualDisk::on_size_allocate( Gtk::Allocation & allocation )
 	
 	//and calculate the rest..
 	calc_position_and_height( visual_partitions, MAIN_BORDER, MAIN_BORDER ) ;//0, 0 ) ;
-	calc_used_unused( visual_partitions ) ;
+	calc_usage( visual_partitions ) ;
 	calc_text( visual_partitions ) ;
+	queue_draw();
 }
 
 int DrawingAreaVisualDisk::spreadout_leftover_px( std::vector<visual_partition> & visual_partitions, int pixels ) 
@@ -415,7 +440,7 @@ void DrawingAreaVisualDisk::free_colors( std::vector<visual_partition> & visual_
 {
 	for ( unsigned int t = 0 ; t < visual_partitions .size() ; t++ )
 	{
-		get_colormap() ->free_colors( visual_partitions[ t ] .color, 1 ) ;
+		get_colormap() ->free_color( visual_partitions[ t ] .color ) ;
 
 		if ( visual_partitions[ t ] .logicals .size() > 0 )
 			free_colors( visual_partitions[ t ] .logicals ) ;
@@ -427,9 +452,10 @@ DrawingAreaVisualDisk::~DrawingAreaVisualDisk()
 	clear() ;
 
 	//free the allocated colors
-	get_colormap() ->free_colors( color_used, 1 ) ;
-	get_colormap() ->free_colors( color_unused, 1 ) ;
-	get_colormap() ->free_colors( color_text, 1 ) ;
+	get_colormap() ->free_color( color_used ) ;
+	get_colormap() ->free_color( color_unused ) ;
+	get_colormap() ->free_color( color_unallocated ) ;
+	get_colormap() ->free_color( color_text ) ;
 }
 
 } //GParted
