@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart
+ * Copyright (C) 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
 #include "../include/Frame_Resizer_Base.h"
@@ -21,6 +21,7 @@ Frame_Resizer_Base::Frame_Resizer_Base()
 {
 	BORDER = 8 ;
 	GRIPPER = 10 ;
+	X_MIN_SPACE_BEFORE = 0 ;
 
 	fixed_start = false ;
 	init() ;
@@ -68,14 +69,14 @@ void Frame_Resizer_Base::init()
 
 void Frame_Resizer_Base::set_rgb_partition_color( const Gdk::Color & color )
 {
-	this ->get_colormap() ->free_colors( color_partition, 1 ) ;
+	this ->get_colormap() ->free_color( color_partition ) ;
 	this ->color_partition = color ;
 	this ->get_colormap() ->alloc_color( color_partition ) ;
 }
 
 void Frame_Resizer_Base::override_default_rgb_unused_color( const Gdk::Color & color ) 
 {
-	this ->get_colormap() ->free_colors( color_unused, 1 ) ;
+	this ->get_colormap() ->free_color( color_unused ) ;
 	this ->color_unused = color ;
 	this ->get_colormap() ->alloc_color( color_unused ) ;
 }
@@ -85,6 +86,11 @@ void Frame_Resizer_Base::set_x_start( int x_start )
 	this ->X_START = x_start + GRIPPER ;
 } 
 
+void Frame_Resizer_Base::set_x_min_space_before( int x_min_space_before ) 
+{
+	this ->X_MIN_SPACE_BEFORE = x_min_space_before ;
+}
+
 void Frame_Resizer_Base::set_x_end( int x_end ) 
 { 
 	this ->X_END = x_end + GRIPPER + BORDER * 2 ; 
@@ -147,7 +153,7 @@ bool Frame_Resizer_Base::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 	{
 		if ( GRIP_LEFT )
 		{
-			if ( ev ->x > GRIPPER &&
+			if ( ev ->x > (GRIPPER + X_MIN_SPACE_BEFORE) &&
 			     (X_END - ev ->x) < MAX_SIZE &&
 			     (X_END - ev ->x) > MIN_SIZE )
 			{
@@ -161,8 +167,8 @@ bool Frame_Resizer_Base::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 				{
 					X_START = X_END - MAX_SIZE ;
 
-					if ( X_START < GRIPPER )
-						X_START = GRIPPER ;
+					if ( X_START < (GRIPPER + X_MIN_SPACE_BEFORE) )
+						X_START = GRIPPER + X_MIN_SPACE_BEFORE ;
 			
 					//-1 to force the spinbutton to its max.
 					signal_resize .emit( X_START - GRIPPER -1,
@@ -170,11 +176,11 @@ bool Frame_Resizer_Base::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 							     ARROW_LEFT ) ; 
 				}
 			}
-			else if ( ev ->x <= GRIPPER )
+			else if ( ev ->x <= (GRIPPER + X_MIN_SPACE_BEFORE) )
 			{
-				if ( X_START > GRIPPER && X_END - X_START < MAX_SIZE )
+				if ( X_START > (GRIPPER + X_MIN_SPACE_BEFORE) && X_END - X_START < MAX_SIZE )
 				{
-					X_START = GRIPPER ;
+					X_START = GRIPPER + X_MIN_SPACE_BEFORE ;
 				
 					signal_resize .emit( X_START - GRIPPER,
 							     X_END - GRIPPER - BORDER * 2,
@@ -249,17 +255,17 @@ bool Frame_Resizer_Base::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 		{
 			temp_x = X_START + static_cast<int>( ev ->x - X_START_MOVE );
 			temp_y = X_END - X_START ;
-		
-			if ( temp_x > GRIPPER && temp_x + temp_y < 500 + GRIPPER + BORDER * 2 )
+
+			if ( temp_x > (GRIPPER + X_MIN_SPACE_BEFORE) && temp_x + temp_y < 500 + GRIPPER + BORDER * 2 )
 			{
 				X_START = temp_x ;
 				X_END = X_START + temp_y ;
 			}
-			else if ( temp_x <= GRIPPER )
+			else if ( temp_x <= (GRIPPER + X_MIN_SPACE_BEFORE) )
 			{
-				if ( X_START > GRIPPER )
+				if ( X_START > (GRIPPER + X_MIN_SPACE_BEFORE) )
 				{
-					X_START = GRIPPER ;
+					X_START = GRIPPER + X_MIN_SPACE_BEFORE;
 					X_END = X_START + temp_y ;
 				}
 			}
@@ -271,8 +277,8 @@ bool Frame_Resizer_Base::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 					X_START = X_END - temp_y ;
 				}
 			}
-			
-			X_START_MOVE = static_cast<int>( ev ->x ) ;		
+
+			X_START_MOVE = static_cast<int>( ev ->x ) ;
 			signal_move .emit( X_START - GRIPPER, X_END - GRIPPER - BORDER * 2 ) ;
 		}
 		
@@ -421,15 +427,13 @@ void Frame_Resizer_Base::Draw_Resize_Grip( ArrowType arrow_type )
 
 Frame_Resizer_Base::~Frame_Resizer_Base()
 { 
-	this ->get_colormap() ->free_colors( color_used, 1 ) ;
-	this ->get_colormap() ->free_colors( color_unused, 1 ) ;
-	this ->get_colormap() ->free_colors( color_arrow, 1 ) ;
-	this ->get_colormap() ->free_colors( color_background, 1 ) ;
-	this ->get_colormap() ->free_colors( color_partition, 1 ) ;
-	this ->get_colormap() ->free_colors( color_arrow_rectangle, 1 ) ;
+	this ->get_colormap() ->free_color( color_used ) ;
+	this ->get_colormap() ->free_color( color_unused ) ;
+	this ->get_colormap() ->free_color( color_arrow ) ;
+	this ->get_colormap() ->free_color( color_background ) ;
+	this ->get_colormap() ->free_color( color_partition ) ;
+	this ->get_colormap() ->free_color( color_arrow_rectangle ) ;
 	
-	if ( cursor_resize )
-		delete cursor_resize ;
-	if ( cursor_move )
-		delete cursor_move ;
+	delete cursor_resize;
+	delete cursor_move;
 }
