@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart
+ * Copyright (C) 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
 #include "../include/Frame_Resizer_Extended.h"
@@ -35,19 +35,20 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 	{
 		if ( GRIP_LEFT )
 		{
-			if (  ev ->x > GRIPPER && 
-		  	      ev->x < X_END - BORDER *2 && 
-		     	      ( ev ->x < USED_START || USED == 0 ) ) 
+			if (  ev ->x > (GRIPPER + X_MIN_SPACE_BEFORE) &&
+			      ev ->x < (X_END - MIN_SIZE - BORDER * 2) &&
+			      ( ev ->x < USED_START || USED == 0 )
+			   )
 			{
 				X_START = static_cast<int>( ev ->x ) ;
 				
 				signal_resize .emit( X_START - GRIPPER, X_END - GRIPPER - BORDER * 2, ARROW_LEFT ) ; 
 			}
-			else if ( ev ->x <= GRIPPER )
+			else if ( ev ->x <= (GRIPPER + X_MIN_SPACE_BEFORE) )
 			{
-				if ( X_START > GRIPPER )
+				if ( X_START > (GRIPPER + X_MIN_SPACE_BEFORE) )
 				{
-					X_START = GRIPPER ;
+					X_START = GRIPPER + X_MIN_SPACE_BEFORE ;
 
 					signal_resize .emit( X_START - GRIPPER,
 							     X_END - GRIPPER - BORDER * 2,
@@ -66,11 +67,11 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 							     ARROW_LEFT ) ;
 				}
 			}
-			else if ( USED == 0 && ev ->x >= X_END - BORDER * 2 )
+			else if ( USED == 0 && ev ->x >= (X_END - MIN_SIZE - BORDER * 2) )
 			{
 				if ( X_START < X_END - BORDER * 2 )
 				{
-					X_START = X_END - BORDER * 2 ;
+					X_START = X_END - MIN_SIZE - BORDER * 2 ;
 					
 					signal_resize .emit( X_START - GRIPPER,
 							     X_END - GRIPPER - BORDER * 2,
@@ -81,7 +82,7 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 		else if ( GRIP_RIGHT )
 		{
 			if ( ev ->x < 500 + GRIPPER + BORDER * 2 && 
-			     ev ->x > X_START + BORDER *2 &&
+			     ev ->x > (X_START + MIN_SIZE + BORDER * 2) &&
 			     ( ev ->x > USED_START + USED + BORDER *2 || USED == 0 ) )
 			{
 				X_END = static_cast<int>( ev ->x ) ;
@@ -110,11 +111,11 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 							     X_END - GRIPPER - BORDER * 2 -1, ARROW_RIGHT ) ;
 				}
 			}
-			else if ( USED == 0 && ev ->x <= X_START + BORDER *2 )
+			else if ( USED == 0 && ev ->x <= (X_START + MIN_SIZE + BORDER * 2) )
 			{
-				if ( X_END > X_START + BORDER *2 )
+				if ( X_END > (X_START + MIN_SIZE + BORDER * 2) )
 				{
-					X_END = X_START + BORDER *2 ;
+					X_END = X_START + MIN_SIZE + BORDER *2 ;
 					
 					signal_resize .emit( X_START - GRIPPER,
 							     X_END - GRIPPER - BORDER * 2,
@@ -144,7 +145,7 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 			drawingarea .get_parent_window() ->set_cursor( *cursor_resize ) ;
 		//normal pointer
 		else 
-			drawingarea .get_parent_window() ->set_cursor( *cursor_normal ) ;		
+			drawingarea .get_parent_window() ->set_cursor() ;		
 	}
 	
 	return true ;
