@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart 'plors' Hakvoort
+ * Copyright (C) 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "../include/OperationCopy.h"
@@ -27,7 +27,7 @@ OperationCopy::OperationCopy( const Device & device,
 {
 	type = OPERATION_COPY ;
 
-	this ->device = device ;
+	this->device = device.get_copy_without_partitions();
 	this ->partition_original = partition_orig ;
 	this ->partition_new = partition_new ;
 	this ->partition_copied = partition_copied ;
@@ -38,36 +38,12 @@ OperationCopy::OperationCopy( const Device & device,
 	
 void OperationCopy::apply_to_visual( std::vector<Partition> & partitions ) 
 {
-	index = index_extended = -1 ;
-	
-	if ( partition_original .inside_extended )
-	{
-		index_extended = find_index_extended( partitions ) ;
-		
-		if ( index_extended >= 0 )
-			index = find_index_original( partitions[ index_extended ] .logicals ) ;
-
-		if ( index >= 0 )
-		{
-			partitions[ index_extended ] .logicals[ index ] = partition_new ; 	
-
-			insert_unallocated( partitions[ index_extended ] .logicals,
-					    partitions[ index_extended ] .sector_start,
-					    partitions[ index_extended ] .sector_end,
-				    	    true ) ;
-		}
-	}
+	if ( partition_original.type == TYPE_UNALLOCATED )
+		// Paste into unallocated space creating new partition
+		insert_new( partitions );
 	else
-	{
-		index = find_index_original( partitions ) ;
-
-		if ( index >= 0 )
-		{
-			partitions[ index ] = partition_new ;
-		
-			insert_unallocated( partitions, 0, device .length -1, false ) ;
-		}
-	}
+		// Paste into existing partition
+		substitute_new( partitions );
 }
 
 void OperationCopy::create_description() 
@@ -78,7 +54,7 @@ void OperationCopy::create_description()
 		description = String::ucompose( _("Copy %1 to %2 (start at %3)"),
 					        partition_copied .get_path(),
 					        device .get_path(),
-					        Utils::format_size( partition_new .sector_start ) ) ;
+					        Utils::format_size( partition_new .sector_start, partition_new .sector_size ) ) ;
 	}
 	else
 	{
@@ -89,5 +65,9 @@ void OperationCopy::create_description()
 	}
 }
 
-} //GParted
+bool OperationCopy::merge_operations( const Operation & candidate )
+{
+	return false;  // Never merge copy operations
+}
 
+} //GParted
