@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart 'plors' Hakvoort
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "../include/OperationResizeMove.h"
@@ -25,15 +25,14 @@ OperationResizeMove::OperationResizeMove( const Device & device,
 				  	  const Partition & partition_new )
 {
 	type = OPERATION_RESIZE_MOVE ;
-	this ->device = device ;
+
+	this->device = device.get_copy_without_partitions();
 	this ->partition_original = partition_orig ;
 	this ->partition_new = partition_new ;
 }
 	
 void OperationResizeMove::apply_to_visual( std::vector<Partition> & partitions ) 
 {
-	index = index_extended = -1 ;
-	
 	if ( partition_original .type == GParted::TYPE_EXTENDED )
 		apply_extended_to_visual( partitions ) ;
 	else 
@@ -57,14 +56,14 @@ void OperationResizeMove::create_description()
 	} ;
 	Action action = NONE ;
 
-	if ( partition_new .get_length() > partition_original .get_length() ) {
+	if ( partition_new .get_sector_length() > partition_original .get_sector_length() ) {
 		//Grow partition
 		action = GROW ;
 		if ( partition_new .sector_start > partition_original .sector_start )
 			action = MOVE_RIGHT_GROW ;
 		if ( partition_new .sector_start < partition_original .sector_start )
 			action = MOVE_LEFT_GROW ;
-	} else if ( partition_new .get_length() < partition_original .get_length() ) {
+	} else if ( partition_new .get_sector_length() < partition_original .get_sector_length() ) {
 		//Shrink partition
 		action = SHRINK ;
 		if ( partition_new .sector_start > partition_original .sector_start )
@@ -84,7 +83,7 @@ void OperationResizeMove::create_description()
 		case NONE		:
 			description = String::ucompose( _("resize/move %1"), partition_original .get_path() ) ;
 			description += " (" ;
-			description += _("new and old partition have the same size and position -- continuing anyway") ;
+			description += _("new and old partition have the same size and position.  Hence continuing anyway") ;
 			description += ")" ;
 			break ;
 		case MOVE_RIGHT		:
@@ -116,28 +115,34 @@ void OperationResizeMove::create_description()
 	if ( ! description .empty() && action != NONE && action != MOVE_LEFT && action != MOVE_RIGHT )
 		description = String::ucompose( description,
 						partition_original .get_path(),
-						Utils::format_size( partition_original .get_length() ),
-						Utils::format_size( partition_new .get_length() ) ) ;
+						Utils::format_size( partition_original .get_sector_length(), partition_original .sector_size ),
+						Utils::format_size( partition_new .get_sector_length(), partition_new .sector_size ) ) ;
 }
 
 void OperationResizeMove::apply_normal_to_visual( std::vector<Partition> & partitions )
 {
+	int index_extended;
+	int index;
+
 	if ( partition_original .inside_extended )
 	{
 		index_extended = find_index_extended( partitions ) ;
 			
 		if ( index_extended >= 0 )
-			index = find_index_original( partitions[ index_extended ] .logicals ) ;
-			
-		if ( index >= 0 )
 		{
-			 partitions[ index_extended ] .logicals[ index ] = partition_new ;
-			 remove_adjacent_unallocated( partitions[ index_extended ] .logicals, index ) ;
+			index = find_index_original( partitions[ index_extended ] .logicals ) ;
 
-			 insert_unallocated( partitions[ index_extended ] .logicals,
-				    	     partitions[ index_extended ] .sector_start,
-				    	     partitions[ index_extended ] .sector_end,
-					     true ) ;
+			if ( index >= 0 )
+			{
+				partitions[index_extended].logicals[index] = partition_new;
+				remove_adjacent_unallocated( partitions[index_extended].logicals, index );
+
+				insert_unallocated( partitions[index_extended].logicals,
+				                    partitions[index_extended].sector_start,
+				                    partitions[index_extended].sector_end,
+				                    device.sector_size,
+				                    true );
+			}
 		}
 	}
 	else
@@ -149,13 +154,15 @@ void OperationResizeMove::apply_normal_to_visual( std::vector<Partition> & parti
 			partitions[ index ] = partition_new ;
 			remove_adjacent_unallocated( partitions, index ) ;
 
-			insert_unallocated( partitions, 0, device .length -1, false ) ;
+			insert_unallocated( partitions, 0, device .length -1, device .sector_size, false ) ;
 		}
 	}
 }
 
 void OperationResizeMove::apply_extended_to_visual( std::vector<Partition> & partitions ) 
 {
+	int index_extended;
+
 	//stuff OUTSIDE extended partition
 	index_extended = find_index_extended( partitions ) ;
 		
@@ -170,7 +177,7 @@ void OperationResizeMove::apply_extended_to_visual( std::vector<Partition> & par
 			partitions[ index_extended ] .sector_end = partition_new .sector_end ;
 		}
 	
-		insert_unallocated( partitions, 0, device .length -1, false ) ;
+		insert_unallocated( partitions, 0, device .length -1, device .sector_size, false ) ;
 	}
 	
 	//stuff INSIDE extended partition
@@ -189,6 +196,7 @@ void OperationResizeMove::apply_extended_to_visual( std::vector<Partition> & par
 		insert_unallocated( partitions[ index_extended ] .logicals,
 				    partitions[ index_extended ] .sector_start,
 				    partitions[ index_extended ] .sector_end,
+				    device .sector_size,
 				    true ) ;
 	}
 }
@@ -205,4 +213,17 @@ void OperationResizeMove::remove_adjacent_unallocated( std::vector<Partition> &
 		partitions .erase( partitions .begin() + ( index_orig -1 ) ) ;
 }
 
+bool OperationResizeMove::merge_operations( const Operation & candidate )
+{
+	if ( candidate.type == OPERATION_RESIZE_MOVE        &&
+	     partition_new  == candidate.partition_original    )
+	{
+		partition_new = candidate.partition_new;
+		create_description();
+		return true;
+	}
+
+	return false;
+}
+
 } //GParted
