@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
 #include "../include/TreeView_Detail.h"
@@ -32,6 +32,7 @@ TreeView_Detail::TreeView_Detail()
 
 	//append columns
 	append_column( _("Partition"), treeview_detail_columns .path );
+	append_column( _("Name"), treeview_detail_columns.name );
 	append_column( _("File System"), treeview_detail_columns .color );
 	append_column( _("Mount Point"), treeview_detail_columns .mountpoint );
 	append_column( _("Label"), treeview_detail_columns .label );
@@ -53,30 +54,30 @@ TreeView_Detail::TreeView_Detail()
 	
 	//FILE SYSTEM
 	//file system text
-	get_column( 1 ) ->pack_start( treeview_detail_columns .filesystem, true );
-	
+	get_column( 2 )->pack_start( treeview_detail_columns.filesystem, true );
+
 	//colored text in File System column 
-	std::vector<Gtk::CellRenderer*> renderers = get_column( 1 ) ->get_cell_renderers() ;
+	std::vector<Gtk::CellRenderer*> renderers = get_column( 2 )->get_cell_renderers();
 	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( renderers .back() ) ;
-	get_column( 1 ) ->add_attribute( cell_renderer_text ->property_foreground(),
-					 treeview_detail_columns .text_color );
-	
+	get_column( 2 )->add_attribute( cell_renderer_text->property_foreground(),
+	                                treeview_detail_columns.text_color );
+
 	//pixbuf and text are both left aligned
-	get_column( 1 ) ->get_first_cell_renderer() ->property_xalign() = Gtk::ALIGN_LEFT ;
+	get_column( 2 )->get_first_cell_renderer()->property_xalign() = Gtk::ALIGN_LEFT;
 	cell_renderer_text ->property_xalign() = Gtk::ALIGN_LEFT ;
 	
 	//MOUNT POINT
 	//colored text in mount point column 
-	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( get_column( 2 ) ->get_first_cell_renderer() );
-	get_column( 2 ) ->add_attribute( cell_renderer_text ->property_foreground(), 
-					 treeview_detail_columns .mount_text_color );
+	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( get_column( 3 )->get_first_cell_renderer() );
+	get_column( 3 )->add_attribute( cell_renderer_text->property_foreground(),
+	                                treeview_detail_columns.mount_text_color );
 
 	//set alignment of numeric columns to right
-	for( short t = 4 ; t < 7 ; t++ )
+	for( short t = 5 ; t < 8 ; t++ )
 		get_column_cell_renderer( t ) ->property_xalign() = 1 ;
 
 	//expand columns and centeralign the headertext
-	for( short t = 4 ; t < 8 ; t++ )
+	for( short t = 5 ; t < 9 ; t++ )
 	{
 		get_column( t ) ->set_expand( true ) ;
 		get_column( t ) ->set_alignment( 0.5 ) ;
@@ -85,22 +86,23 @@ TreeView_Detail::TreeView_Detail()
 
 void TreeView_Detail::load_partitions( const std::vector<Partition> & partitions ) 
 {
-	bool mountpoints = false, labels = false ;
+	bool mountpoints = false, labels = false, names = false;
 	treestore_detail ->clear() ;
-	
-	load_partitions( partitions, mountpoints, labels ) ;
 
-	get_column( 2 ) ->set_visible( mountpoints ) ;
-	get_column( 3 ) ->set_visible( labels ) ;
-	
+	load_partitions( partitions, mountpoints, labels, names );
+
+	get_column( 1 )->set_visible( names );
+	get_column( 3 )->set_visible( mountpoints );
+	get_column( 4 )->set_visible( labels );
+
 	columns_autosize();
 	expand_all() ;
 }
 
-void TreeView_Detail::set_selected( const Partition & partition )
+void TreeView_Detail::set_selected( const Partition * partition_ptr )
 {
 	block = true ;
-	set_selected( treestore_detail ->children(), partition ) ;
+	set_selected( treestore_detail->children(), partition_ptr );
 	block = false ;
 }
 
@@ -110,9 +112,10 @@ void TreeView_Detail::clear()
 }
 
 void TreeView_Detail::load_partitions( const std::vector<Partition> & partitions,
-				       bool & mountpoints,
-				       bool & labels,
-				       const Gtk::TreeRow & parent_row ) 
+                                       bool & mountpoints,
+                                       bool & labels,
+                                       bool & names,
+                                       const Gtk::TreeRow & parent_row )
 {
 	Gtk::TreeRow row ;
 	for ( unsigned int i = 0 ; i < partitions .size() ; i++ ) 
@@ -121,21 +124,25 @@ void TreeView_Detail::load_partitions( const std::vector<Partition> & partitions
 		create_row( row, partitions[ i ] );
 		
 		if ( partitions[ i ] .type == GParted::TYPE_EXTENDED )
-			load_partitions( partitions[ i ] .logicals, mountpoints, labels, row ) ;
-			
+			load_partitions( partitions[i].logicals, mountpoints, labels, names, row );
+
 		if ( partitions[ i ] .get_mountpoints() .size() )
 			mountpoints = true ;
 					
-		if ( ! partitions[ i ] .label .empty() )
+		if ( ! partitions[ i ].get_filesystem_label().empty() )
 			labels = true ;
+
+		if ( ! partitions[i].name.empty() )
+			names = true;
 	}
 }
 
-bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows, const Partition & partition, bool inside_extended ) 
+bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows,
+                                    const Partition * partition_ptr, bool inside_extended )
 {
 	for ( unsigned int t = 0 ; t < rows .size() ; t++ )
 	{
-		if ( static_cast<Partition>( rows[ t ] [ treeview_detail_columns .partition ] ) == partition )
+		if ( * static_cast<const Partition *>( rows[t][treeview_detail_columns.partition_ptr] ) == *partition_ptr )
 		{
 			if ( inside_extended )
 				expand_all() ;
@@ -144,7 +151,7 @@ bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows, const Partiti
 			return true ;
 		}
 
-		if ( set_selected( rows[ t ] .children(), partition, true ) )
+		if ( set_selected( rows[t].children(), partition_ptr, true ) )
 			return true ;
 	}
 	
@@ -174,6 +181,9 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition
 	if ( partition .type == GParted::TYPE_EXTENDED && partition .busy ) 
 		treerow[ treeview_detail_columns .path ] = treerow[ treeview_detail_columns .path ] + "   " ;
 
+	// name
+	treerow[treeview_detail_columns.name] = partition.name;
+
 	treerow[ treeview_detail_columns .color ] = Utils::get_color_as_pixbuf( partition .filesystem, 16, 16 ) ; 
 
 	treerow[ treeview_detail_columns .filesystem ] = 
@@ -183,25 +193,27 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition
 	treerow[ treeview_detail_columns .mountpoint ] = Glib::build_path( ", ", partition .get_mountpoints() ) ;
 
 	//label
-	treerow[ treeview_detail_columns .label ] = partition .label ;
+	treerow[ treeview_detail_columns .label ] = partition.get_filesystem_label();
 		
 	//size
-	treerow[ treeview_detail_columns .size ] = Utils::format_size( partition .get_length() ) ;
+	treerow[ treeview_detail_columns .size ] = Utils::format_size( partition .get_sector_length(), partition .sector_size ) ;
 	
 	//used
+	Sector used = partition .get_sectors_used() ;
 	treerow[ treeview_detail_columns .used ] =
-		partition .sectors_used == -1 ? "---" : Utils::format_size( partition .sectors_used ) ;
+		used == -1 ? "---" : Utils::format_size( used, partition .sector_size ) ;
 
 	//unused
+	Sector unused = partition .get_sectors_unused() ;
 	treerow[ treeview_detail_columns .unused ] = 
-		partition .sectors_unused == -1 ? "---" : Utils::format_size( partition .sectors_unused ) ;
+		unused == -1 ? "---" : Utils::format_size( unused, partition .sector_size ) ;
 
 	//flags	
 	treerow[ treeview_detail_columns .flags ] = 
 		Glib::build_path( ", ", partition .flags ) ;
-	
-	//hidden column (partition object)
-	treerow[ treeview_detail_columns .partition ] = partition;
+
+	// Hidden column (pointer to partition object)
+	treerow[treeview_detail_columns.partition_ptr] = & partition;
 }
 
 bool TreeView_Detail::on_button_press_event( GdkEventButton * event )
@@ -229,7 +241,7 @@ void TreeView_Detail::on_selection_changed()
 	if ( ! block && treeselection ->get_selected() != 0 )
 	{
 		Gtk::TreeRow row = static_cast<Gtk::TreeRow>( * treeselection ->get_selected() ) ;
-		signal_partition_selected .emit( row[ treeview_detail_columns .partition ], true ) ;
+		signal_partition_selected.emit( row[treeview_detail_columns.partition_ptr], true );
 	}
 }
 	
