@@ -1,4 +1,5 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -8,11 +9,10 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
  
  
@@ -25,7 +25,9 @@ FS reiserfs::get_filesystem_support()
 {
 	FS fs ;
 	fs .filesystem = GParted::FS_REISERFS ;
-	
+
+	fs .busy = FS::GPARTED ;
+
 	if ( ! Glib::find_program_in_path( "debugreiserfs" ) .empty() )
 	{
 		fs .read = GParted::FS::EXTERNAL ;
@@ -33,10 +35,17 @@ FS reiserfs::get_filesystem_support()
 	}
 
 	if ( ! Glib::find_program_in_path( "reiserfstune" ) .empty() )
+	{
 		fs .write_label = FS::EXTERNAL ;
+		fs .read_uuid = FS::EXTERNAL ;
+		fs .write_uuid = FS::EXTERNAL ;
+	}
 
 	if ( ! Glib::find_program_in_path( "mkreiserfs" ) .empty() )
+	{
 		fs .create = GParted::FS::EXTERNAL ;
+		fs .create_with_label = GParted::FS::EXTERNAL ;
+	}
 	
 	if ( ! Glib::find_program_in_path( "reiserfsck" ) .empty() )
 		fs .check = GParted::FS::EXTERNAL ;
@@ -56,7 +65,14 @@ FS reiserfs::get_filesystem_support()
 		fs .move = GParted::FS::GPARTED ;
 	}
 
-	fs .MIN = 32 * MEBIBYTE ;
+	fs .online_read = FS::GPARTED ;
+#ifdef ENABLE_ONLINE_RESIZE
+	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
+		fs. online_grow = fs. grow ;
+#endif
+
+	//Actual minimum is at least 18 blocks larger than 32 MiB for the journal offset
+	fs .MIN = 34 * MEBIBYTE ;
 	
 	return fs ;
 }
@@ -65,7 +81,12 @@ void reiserfs::set_used_sectors( Partition & partition )
 {
 	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
 	{
-		index = output .find( "Blocksize" ) ;
+		index = output .find( "Count of blocks on the device:" ) ;
+		if ( index >= output .length() ||
+		     sscanf( output .substr( index ) .c_str(), "Count of blocks on the device: %Ld", &T ) != 1 )
+			T = -1 ;
+
+		index = output .find( "Blocksize:" ) ;
 		if ( index >= output .length() || 
 		     sscanf( output .substr( index ) .c_str(), "Blocksize: %Ld", &S ) != 1 )
 			S = -1 ;
@@ -75,8 +96,12 @@ void reiserfs::set_used_sectors( Partition & partition )
 		     sscanf( output .substr( index ) .c_str(), "%Ld", &N ) != 1 )
 			N = -1 ;
 
-		if ( N > -1 && S > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / 512.0 ) ) ) ;
+		if ( T > -1 && N > -1 && S > -1 )
+		{
+			T = Utils::round( T * ( S / double(partition .sector_size) ) ) ;
+			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
+			partition .set_sector_usage( T, N ) ;
+		}
 	}
 	else
 	{
@@ -90,10 +115,9 @@ void reiserfs::set_used_sectors( Partition & partition )
 
 void reiserfs::read_label( Partition & partition )
 {
-	//FIXME: i think running debugreiserfs takes a long time on filled file systems, test for this...
 	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
 	{
-		partition .label = Utils::regexp_label( output, "^label:[\t ]*(.*)$" ) ;
+		partition.set_filesystem_label( Utils::regexp_label( output, "^label:[\t ]*(.*)$" ) );
 	}
 	else
 	{
@@ -107,42 +131,68 @@ void reiserfs::read_label( Partition & partition )
 	
 bool reiserfs::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "reiserfstune --label \"" + partition .label + "\" " + partition .get_path(), operationdetail ) ;
+	return ! execute_command( "reiserfstune --label \"" + partition.get_filesystem_label() + "\" " +
+	                          partition.get_path(),
+	                          operationdetail, EXEC_CHECK_STATUS );
+}
+
+void reiserfs::read_uuid( Partition & partition )
+{
+	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
+	{
+		partition .uuid = Utils::regexp_label( output, "^UUID:[[:blank:]]*(" RFC4122_NONE_NIL_UUID_REGEXP ")" ) ;
+	}
+	else
+	{
+		if ( ! output .empty() )
+			partition .messages .push_back( output ) ;
+
+		if ( ! error .empty() )
+			partition .messages .push_back( error ) ;
+	}
+}
+
+bool reiserfs::write_uuid( const Partition & partition, OperationDetail & operationdetail )
+{
+	return ! execute_command( "reiserfstune -u random " + partition.get_path(),
+	                          operationdetail, EXEC_CHECK_STATUS );
 }
 
 bool reiserfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkreiserfs -f --label \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkreiserfs -f -f --label \"" + new_partition.get_filesystem_label() + "\" " +
+	                          new_partition.get_path(),
+	                          operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE );
 }
 
 bool reiserfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 { 
-	Glib::ustring str_temp = "echo y | resize_reiserfs " + partition_new .get_path() ;
-	
+	Glib::ustring size = "" ;
 	if ( ! fill_partition )
 	{
-		str_temp += " -s " ;
-		str_temp += Utils::num_to_str( Utils::round( Utils::sector_to_unit(
-				partition_new .get_length(), GParted::UNIT_BYTE ) ) -1, true ) ;
+		size = " -s " + Utils::num_to_str( floor( Utils::sector_to_unit(
+		                   partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) ) ;
 	}
+	Glib::ustring cmd = "sh -c 'echo y | resize_reiserfs" + size + " " + partition_new .get_path() + "'" ;
 
-	exit_status = execute_command( str_temp, operationdetail ) ;
-
-	return ( exit_status == 0 || exit_status == 256 ) ;
-}
-
-bool reiserfs::copy( const Glib::ustring & src_part_path,
-		     const Glib::ustring & dest_part_path,
-		     OperationDetail & operationdetail )
-{	
-	return true ;
+	exit_status = execute_command( cmd, operationdetail ) ;
+	// NOTE: Neither resize_reiserfs manual page nor the following commit, which first
+	// added this check, indicate why exit status 1 also indicates success.  Commit
+	// from 2006-05-23:
+	//     7bb7e8a84f164cd913384509a6adc3739a9d8b78
+	//     Use ped_device_read and ped_device_write instead of 'dd' to copy
+	bool success = ( exit_status == 0 || exit_status == 1 );
+	set_status( operationdetail, success );
+	return success;
 }
 
 bool reiserfs::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	exit_status = execute_command( "reiserfsck --yes --fix-fixable --quiet " + partition .get_path(), operationdetail ) ;
-	
-	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
+	exit_status = execute_command( "reiserfsck --yes --fix-fixable --quiet " + partition.get_path(),
+	                               operationdetail, EXEC_CANCEL_SAFE );
+	bool success = ( exit_status == 0 || exit_status == 1 );
+	set_status( operationdetail, success );
+	return success;
 }
 
 } //GParted
